@@ -27,20 +27,23 @@ using namespace scim;
 
 class AnthyInstance;
 
-class AnthyAction
+namespace scim_anthy {
+
+class Action
 {
     typedef bool (AnthyInstance::*PMF) (void);
     typedef bool (*Func)               (AnthyInstance *anthy);
 
 public:
-    AnthyAction  (const String &name, const String &key_bindings, PMF pmf);
-    AnthyAction  (const String &name, const String &key_bindings, Func func);
-    ~AnthyAction ();
+    Action  (const String &name, const String &key_bindings, PMF pmf);
+    Action  (const String &name, const String &key_bindings, Func func);
+    ~Action ();
 
 public:
     bool perform (AnthyInstance  *performer);
     bool perform (AnthyInstance  *performer,
                   const KeyEvent &key);
+    
 
 private:
     bool match_key_event (const KeyEvent &key);
@@ -53,4 +56,6 @@ private:
     KeyEventList   m_key_bindings;
 };
 
+}
+
 #endif /* __SCIM_ANTHY_ACTION_H__ */
