@@ -108,6 +108,7 @@ AnthyFactory::AnthyFactory (const String &lang,
       m_typing_method               (SCIM_ANTHY_CONFIG_TYPING_METHOD_DEFAULT),
       m_conversion_mode             (SCIM_ANTHY_CONFIG_CONVERSION_MODE_DEFAULT),
       m_period_style                (SCIM_ANTHY_CONFIG_PERIOD_STYLE_DEFAULT),
+      m_symbol_style                (SCIM_ANTHY_CONFIG_SYMBOL_STYLE_DEFAULT),
       m_space_type                  (SCIM_ANTHY_CONFIG_SPACE_TYPE_DEFAULT),
       m_ten_key_type                (SCIM_ANTHY_CONFIG_TEN_KEY_TYPE_DEFAULT),
       m_behavior_on_period          (SCIM_ANTHY_CONFIG_BEHAVIOR_ON_PERIOD_DEFAULT),
@@ -129,6 +130,7 @@ AnthyFactory::AnthyFactory (const String &lang,
       m_show_conv_mode_label        (SCIM_ANTHY_CONFIG_SHOW_INPUT_MODE_LABEL_DEFAULT),
       m_show_typing_method_label    (SCIM_ANTHY_CONFIG_SHOW_TYPING_METHOD_LABEL_DEFAULT),
       m_show_period_style_label     (SCIM_ANTHY_CONFIG_SHOW_PERIOD_STYLE_LABEL_DEFAULT),
+      m_show_symbol_style_label     (SCIM_ANTHY_CONFIG_SHOW_SYMBOL_STYLE_LABEL_DEFAULT),
       m_show_dict_label             (SCIM_ANTHY_CONFIG_SHOW_DICT_LABEL_DEFAULT),
       m_show_dict_admin_label       (SCIM_ANTHY_CONFIG_SHOW_DICT_ADMIN_LABEL_DEFAULT),
       m_show_add_word_label         (SCIM_ANTHY_CONFIG_SHOW_ADD_WORD_LABEL_DEFAULT),
@@ -200,7 +202,9 @@ WideString
 AnthyFactory::get_credits () const
 {
     return utf8_mbstowcs (
-        _("Special thanks:\n"
+        _("Art work:\n"
+          "  SHIMODA Hiroshi <piro@p.club.ne.jp>\n"
+          "Special thanks:\n"
           "  UTUMI Hirosi <utuhiro78@yahoo.co.jp>\n"
           "  Yukiko Bando <ybando@k6.dion.ne.jp>\n"
           "  Mike Fabian <mfabian@suse.de>\n"
@@ -434,6 +438,10 @@ AnthyFactory::reload_config (const ConfigPointer &config)
             = config->read (String (SCIM_ANTHY_CONFIG_PERIOD_STYLE),
                             String (SCIM_ANTHY_CONFIG_PERIOD_STYLE_DEFAULT));
 
+        m_symbol_style
+            = config->read (String (SCIM_ANTHY_CONFIG_SYMBOL_STYLE),
+                            String (SCIM_ANTHY_CONFIG_SYMBOL_STYLE_DEFAULT));
+
         m_space_type
             = config->read (String (SCIM_ANTHY_CONFIG_SPACE_TYPE),
                             String (SCIM_ANTHY_CONFIG_SPACE_TYPE_DEFAULT));
@@ -526,6 +534,10 @@ AnthyFactory::reload_config (const ConfigPointer &config)
             = config->read (String (SCIM_ANTHY_CONFIG_SHOW_PERIOD_STYLE_LABEL),
                             SCIM_ANTHY_CONFIG_SHOW_PERIOD_STYLE_LABEL_DEFAULT);
 
+        m_show_symbol_style_label
+            = config->read (String (SCIM_ANTHY_CONFIG_SHOW_SYMBOL_STYLE_LABEL),
+                            SCIM_ANTHY_CONFIG_SHOW_SYMBOL_STYLE_LABEL_DEFAULT);
+
         m_show_dict_label
             = config->read (String (SCIM_ANTHY_CONFIG_SHOW_DICT_LABEL),
                             SCIM_ANTHY_CONFIG_SHOW_DICT_LABEL_DEFAULT);
