@@ -75,6 +75,7 @@ public:
     String         m_typing_method;
     String         m_conversion_mode;
     String         m_period_style;
+    String         m_symbol_style;
     String         m_space_type;
     String         m_ten_key_type;
     String         m_behavior_on_period;
@@ -104,6 +105,7 @@ public:
     bool           m_show_conv_mode_label;
     bool           m_show_typing_method_label;
     bool           m_show_period_style_label;
+    bool           m_show_symbol_style_label;
     bool           m_show_dict_label;
     bool           m_show_dict_admin_label;
     bool           m_show_add_word_label;
