@@ -70,10 +70,25 @@
 #define SCIM_PROP_PERIOD_STYLE_WIDE_LATIN_JAPANESE \
                                              "/IMEngine/Anthy/PeriodType/WideRatin_Japanese"
 
+#define SCIM_PROP_SYMBOL_STYLE               "/IMEngine/Anthy/SymbolType"
+#define SCIM_PROP_SYMBOL_STYLE_JAPANESE      "/IMEngine/Anthy/SymbolType/Japanese"
+#define SCIM_PROP_SYMBOL_STYLE_BRACKET_SLASH "/IMEngine/Anthy/SymbolType/WideBracket_WideSlash"
+#define SCIM_PROP_SYMBOL_STYLE_CORNER_BRACKET_SLASH \
+                                             "/IMEngine/Anthy/SymbolType/CornerBracket_WideSlash"
+#define SCIM_PROP_SYMBOL_STYLE_BRACKET_MIDDLE_DOT \
+                                             "/IMEngine/Anthy/SymbolType/WideBracket_MiddleDot"
+
 #define SCIM_PROP_DICT                       "/IMEngine/Anthy/Dictionary"
 #define SCIM_PROP_DICT_ADD_WORD              "/IMEngine/Anthy/Dictionary/AddWord"
 #define SCIM_PROP_DICT_LAUNCH_ADMIN_TOOL     "/IMEngine/Anthy/Dictionary/LaunchAdminTool"
 
+#define UTF8_BRACKET_CORNER_BEGIN "\xE3\x80\x8C"
+#define UTF8_BRACKET_CORNER_END   "\xE3\x80\x8D"
+#define UTF8_BRACKET_WIDE_BEGIN   "\xEF\xBC\xBB"
+#define UTF8_BRACKET_WIDE_END     "\xEF\xBC\xBD"
+#define UTF8_MIDDLE_DOT           "\xE3\x83\xBB"
+#define UTF8_SLASH_WIDE           "\xEF\xBC\x8F"
+
 AnthyInstance::AnthyInstance (AnthyFactory   *factory,
                               const String   &encoding,
                               int             id)
@@ -611,6 +626,56 @@ AnthyInstance::install_properties (void)
             m_properties.push_back (prop);
         }
 
+        if (m_factory->m_show_symbol_style_label) {
+            prop = Property (SCIM_PROP_SYMBOL_STYLE,
+                             UTF8_BRACKET_CORNER_BEGIN
+                             UTF8_BRACKET_CORNER_END
+                             UTF8_MIDDLE_DOT,
+                             String (""),
+                             _("Symbol style"));
+            m_properties.push_back (prop);
+
+            prop = Property (SCIM_PROP_SYMBOL_STYLE_JAPANESE,
+                             UTF8_BRACKET_CORNER_BEGIN
+                             UTF8_BRACKET_CORNER_END
+                             UTF8_MIDDLE_DOT,
+                             String (""),
+                             UTF8_BRACKET_CORNER_BEGIN
+                             UTF8_BRACKET_CORNER_END
+                             UTF8_MIDDLE_DOT);
+            m_properties.push_back (prop);
+
+            prop = Property (SCIM_PROP_SYMBOL_STYLE_CORNER_BRACKET_SLASH,
+                             UTF8_BRACKET_CORNER_BEGIN
+                             UTF8_BRACKET_CORNER_END
+                             UTF8_SLASH_WIDE,
+                             String (""),
+                             UTF8_BRACKET_CORNER_BEGIN
+                             UTF8_BRACKET_CORNER_END
+                             UTF8_SLASH_WIDE);
+            m_properties.push_back (prop);
+
+            prop = Property (SCIM_PROP_SYMBOL_STYLE_BRACKET_MIDDLE_DOT,
+                             UTF8_BRACKET_WIDE_BEGIN
+                             UTF8_BRACKET_WIDE_END
+                             UTF8_MIDDLE_DOT,
+                             String (""),
+                             UTF8_BRACKET_WIDE_BEGIN
+                             UTF8_BRACKET_WIDE_END
+                             UTF8_MIDDLE_DOT);
+            m_properties.push_back (prop);
+
+            prop = Property (SCIM_PROP_SYMBOL_STYLE_BRACKET_SLASH,
+                             UTF8_BRACKET_WIDE_BEGIN
+                             UTF8_BRACKET_WIDE_END
+                             UTF8_SLASH_WIDE,
+                             String (""),
+                             UTF8_BRACKET_WIDE_BEGIN
+                             UTF8_BRACKET_WIDE_END
+                             UTF8_SLASH_WIDE);
+            m_properties.push_back (prop);
+        }
+
         if (m_factory->m_show_dict_label) {
             prop = Property (SCIM_PROP_DICT,
                              String(""), //_("Dictionary"),
@@ -641,6 +706,8 @@ AnthyInstance::install_properties (void)
     set_typing_method (get_typing_method ());
     set_period_style (m_preedit.get_period_style (),
                       m_preedit.get_comma_style ());
+    set_symbol_style (m_preedit.get_bracket_style (),
+                      m_preedit.get_slash_style ());
 
     register_properties (m_properties);
 }
@@ -810,6 +877,50 @@ AnthyInstance::set_period_style (PeriodStyle period,
         m_preedit.set_comma_style (comma);
 }
 
+void
+AnthyInstance::set_symbol_style (BracketStyle bracket,
+                                 SlashStyle   slash)
+{
+    String label;
+
+    switch (bracket) {
+    case SCIM_ANTHY_BRACKET_JAPANESE:
+        label = UTF8_BRACKET_CORNER_BEGIN UTF8_BRACKET_CORNER_END;
+        break;
+    case SCIM_ANTHY_BRACKET_WIDE:
+        label = UTF8_BRACKET_WIDE_BEGIN UTF8_BRACKET_WIDE_END;
+        break;
+    default:
+        break;
+    }
+
+    switch (slash) {
+    case SCIM_ANTHY_SLASH_JAPANESE:
+        label += UTF8_MIDDLE_DOT;
+        break;
+    case SCIM_ANTHY_SLASH_WIDE:
+        label += UTF8_SLASH_WIDE;
+        break;
+    default:
+        break;
+    }
+
+    if (label.length () > 0) {
+        PropertyList::iterator it = std::find (m_properties.begin (),
+                                               m_properties.end (),
+                                               SCIM_PROP_SYMBOL_STYLE);
+        if (it != m_properties.end ()) {
+            it->set_label (label.c_str ());
+            update_property (*it);
+        }
+    }
+
+    if (bracket != m_preedit.get_bracket_style ())
+        m_preedit.set_bracket_style (bracket);
+    if (slash != m_preedit.get_slash_style ())
+        m_preedit.set_slash_style (slash);
+}
+
 bool
 AnthyInstance::is_selecting_candidates (void)
 {
@@ -1448,6 +1559,8 @@ AnthyInstance::action_candidates_page_down (void)
 bool
 AnthyInstance::action_select_candidate (unsigned int i)
 {
+    if (!m_lookup_table_visible) return false;
+
     if (m_preedit.is_predicting () && !m_preedit.is_converting () &&
         m_factory->m_use_direct_key_on_predict)
     {
@@ -1959,6 +2072,20 @@ AnthyInstance::trigger_property (const String &property)
         set_period_style (SCIM_ANTHY_PERIOD_HALF,
                           SCIM_ANTHY_COMMA_HALF);
 
+    // symbol type
+    } else if (property == SCIM_PROP_SYMBOL_STYLE_JAPANESE) {
+        set_symbol_style (SCIM_ANTHY_BRACKET_JAPANESE,
+                          SCIM_ANTHY_SLASH_JAPANESE);
+    } else if (property == SCIM_PROP_SYMBOL_STYLE_CORNER_BRACKET_SLASH) {
+        set_symbol_style (SCIM_ANTHY_BRACKET_JAPANESE,
+                          SCIM_ANTHY_SLASH_WIDE);
+    } else if (property == SCIM_PROP_SYMBOL_STYLE_BRACKET_MIDDLE_DOT) {
+        set_symbol_style (SCIM_ANTHY_BRACKET_WIDE,
+                          SCIM_ANTHY_SLASH_JAPANESE);
+    } else if (property == SCIM_PROP_SYMBOL_STYLE_BRACKET_SLASH) {
+        set_symbol_style (SCIM_ANTHY_BRACKET_WIDE,
+                          SCIM_ANTHY_SLASH_WIDE);
+
     // dictionary
     } else if (property == SCIM_PROP_DICT_ADD_WORD) {
         action_add_word ();
@@ -2090,6 +2217,26 @@ AnthyInstance::reload_config (const ConfigPointer &config)
         }
     }
 
+    // set symbol style
+    if (m_on_init || !m_factory->m_show_symbol_style_label) {
+        if (m_factory->m_symbol_style == "Japanese") {
+            m_preedit.set_bracket_style (SCIM_ANTHY_BRACKET_JAPANESE);
+            m_preedit.set_slash_style   (SCIM_ANTHY_SLASH_JAPANESE);
+        } else if (m_factory->m_symbol_style == "WideBracket_WideSlash") {
+            m_preedit.set_bracket_style (SCIM_ANTHY_BRACKET_WIDE);
+            m_preedit.set_slash_style   (SCIM_ANTHY_SLASH_WIDE);
+        } else if (m_factory->m_symbol_style == "CornerBracket_WideSlash") {
+            m_preedit.set_bracket_style (SCIM_ANTHY_BRACKET_JAPANESE);
+            m_preedit.set_slash_style   (SCIM_ANTHY_SLASH_WIDE);
+        } else if (m_factory->m_symbol_style == "WideBracket_MiddleDot") {
+            m_preedit.set_bracket_style (SCIM_ANTHY_BRACKET_WIDE);
+            m_preedit.set_slash_style   (SCIM_ANTHY_SLASH_JAPANESE);
+        } else {
+            m_preedit.set_bracket_style (SCIM_ANTHY_BRACKET_JAPANESE);
+            m_preedit.set_slash_style   (SCIM_ANTHY_SLASH_JAPANESE);
+        }
+    }
+
     // set lookup table
     if (m_factory->m_cand_win_page_size > 0)
         m_lookup_table.set_page_size (m_factory->m_cand_win_page_size);
