@@ -154,6 +154,16 @@ BoolConfigData config_bool_common [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_SHOW_SYMBOL_STYLE_LABEL,
+        SCIM_ANTHY_CONFIG_SHOW_SYMBOL_STYLE_LABEL_DEFAULT,
+        SCIM_ANTHY_CONFIG_SHOW_SYMBOL_STYLE_LABEL_DEFAULT,
+        N_("Show _symbol style label"),
+        NULL,
+        NULL,
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_SHOW_DICT_LABEL,
         SCIM_ANTHY_CONFIG_SHOW_DICT_LABEL_DEFAULT,
@@ -290,6 +300,16 @@ StringConfigData config_string_common [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_SYMBOL_STYLE,
+        SCIM_ANTHY_CONFIG_SYMBOL_STYLE_DEFAULT,
+        SCIM_ANTHY_CONFIG_SYMBOL_STYLE_DEFAULT,
+        N_("Symb_ol input style: "),
+        NULL,
+        NULL,
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_SPACE_TYPE,
         SCIM_ANTHY_CONFIG_SPACE_TYPE_DEFAULT,
