@@ -233,19 +233,28 @@ static ComboConfigCandidate period_styles[] =
     {NULL, NULL},
 };
 
+static ComboConfigCandidate symbol_styles[] =
+{
+    {"\xE3\x80\x8C\xE3\x80\x8D\xE3\x83\xBB", "Japanese"},
+    {"\xE3\x80\x8C\xE3\x80\x8D\xEF\xBC\x8F", "CornerBracket_WideSlash"},
+    {"\xEF\xBC\xBB\xEF\xBC\xBD\xE3\x83\xBB", "WideBracket_MiddleDot"},
+    {"\xEF\xBC\xBB\xEF\xBC\xBD\xEF\xBC\x8F", "WideBracket_WideSlash"},
+    {NULL, NULL},
+};
+
 static ComboConfigCandidate space_types[] =
 {
+    {N_("Follow input mode"), "FollowMode"},
     {N_("Wide"),              "Wide"},
     {N_("Half"),              "Half"},
-    {N_("Follow input mode"), "FollowMode"},
     {NULL, NULL},
 };
 
 static ComboConfigCandidate ten_key_types[] =
 {
+    {N_("Follow input mode"), "FollowMode"},
     {N_("Wide"),              "Wide"},
     {N_("Half"),              "Half"},
-    {N_("Follow input mode"), "FollowMode"},
     {NULL, NULL},
 };
 
@@ -756,7 +765,7 @@ create_common_page (void)
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
 
-    table = gtk_table_new (6, 2, FALSE);
+    table = gtk_table_new (7, 2, FALSE);
     gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
     gtk_widget_show (table);
 
@@ -775,25 +784,45 @@ create_common_page (void)
                            (gpointer) &conversion_modes,
                            GTK_TABLE (table), 2);
 
+    return vbox;
+}
+
+static GtkWidget *
+create_symbols_page (void)
+{
+    GtkWidget *vbox, *table, *widget;
+
+    vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox);
+
+    table = gtk_table_new (7, 2, FALSE);
+    gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
+    gtk_widget_show (table);
+
     /* period style */
     widget = create_combo (SCIM_ANTHY_CONFIG_PERIOD_STYLE,
                            (gpointer) &period_styles,
                            GTK_TABLE (table), 3);
 
+    /* symbol style */
+    widget = create_combo (SCIM_ANTHY_CONFIG_SYMBOL_STYLE,
+                           (gpointer) &symbol_styles,
+                           GTK_TABLE (table), 4);
+
     /* space_style */
     widget = create_combo (SCIM_ANTHY_CONFIG_SPACE_TYPE,
                            (gpointer) &space_types,
-                           GTK_TABLE (table), 4);
+                           GTK_TABLE (table), 5);
 
     /* ten key_style */
     widget = create_combo (SCIM_ANTHY_CONFIG_TEN_KEY_TYPE,
                            (gpointer) &ten_key_types,
-                           GTK_TABLE (table), 5);
+                           GTK_TABLE (table), 6);
 
     /* behavior on period */
     widget = create_combo (SCIM_ANTHY_CONFIG_BEHAVIOR_ON_PERIOD,
                            (gpointer) &behavior_on_period,
-                           GTK_TABLE (table), 6);
+                           GTK_TABLE (table), 7);
 
     return vbox;
 }
@@ -1136,6 +1165,9 @@ create_toolbar_page (void)
     widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_PERIOD_STYLE_LABEL);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 2);
 
+    widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_SYMBOL_STYLE_LABEL);
+    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 2);
+
     /* dictionary menu */
     widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_DICT_LABEL);
     g_signal_connect ((gpointer) widget, "toggled",
@@ -1148,15 +1180,11 @@ create_toolbar_page (void)
     gtk_widget_show (hbox);
     label = gtk_label_new ("    ");
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
     gtk_widget_show (label);
     widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_DICT_ADMIN_LABEL);
     gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 2);
-    gtk_widget_show (hbox);
-    label = gtk_label_new ("    ");
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_widget_show (label);
     widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_ADD_WORD_LABEL);
     gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
@@ -1233,6 +1261,39 @@ create_appearance_page (void)
     return vbox;
 }
 
+static GtkWidget *
+create_about_page ()
+{
+    GtkWidget *vbox, *label;
+    gchar str[256];
+
+    vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox);
+
+    g_snprintf (
+        str, 256,
+        _("<span size=\"20000\">"
+          "%s-%s"
+          "</span>\n\n"
+
+          "<span size=\"16000\" style=\"italic\">"
+          "A Japanese input method module\nfor SCIM using Anthy"
+          "</span>\n\n\n\n"
+
+          "<span size=\"12000\">"
+          "Copyright 2005-2006, Takuro Ashie &lt;ashie@homa.ne.jp&gt;"
+          "</span>"),
+        PACKAGE, PACKAGE_VERSION);
+
+    label = gtk_label_new (NULL);
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
+    gtk_label_set_markup (GTK_LABEL (label), str);
+    gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+    gtk_widget_show (label);
+
+    return vbox;
+}
+
 static GtkWidget *
 create_setup_window (void)
 {
@@ -1251,6 +1312,12 @@ create_setup_window (void)
         gtk_widget_show (label);
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 
+        // Create the symbols page.
+        page = create_symbols_page ();
+        label = gtk_label_new (_("Symbols"));
+        gtk_widget_show (label);
+        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
+
         // Create the key bind page.
         page = create_keyboard_page ();
         label = gtk_label_new (_("Key bindings"));
@@ -1305,6 +1372,12 @@ create_setup_window (void)
         gtk_widget_show (label);
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 
+        // Create the appearance  page.
+        page = create_about_page ();
+        label = gtk_label_new (_("About"));
+        gtk_widget_show (label);
+        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
+
         // for preventing enabling left arrow.
         gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 1);
         gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
